# -----------------------------------------------------------------------------
# Explosions
#
# Copyright 2005 Ron Dippold
# -----------------------------------------------------------------------------
import pygame.sprite, pygame.image
from   pygame.locals import *

import Util

# -----------------------------------------------------------------------------
#
# class Boom
#
# -----------------------------------------------------------------------------


class Boom( pygame.sprite.Sprite ):
	"""
	Booms (explosions) just flip between frames until they run out of life
	and kill themselves off. They come in three sizes.
	We add the effect of 'gravity' to the speed.
	"""

	# Sort of an enum...
	SIZE_SMALL, SIZE_MEDIUM, SIZE_LARGE = range(3)
	# Images for all sizes
	imagesets = None

	@staticmethod
	def preload():
		Boom.imagesets = [ Util.imageset_loader( "boom_s" ),
						   Util.imageset_loader( "boom_m" ),
						   Util.imageset_loader( "boom_l" ) ]
		Boom.sounds = [ Util.sound_loader( "boom_s" ),
						Util.sound_loader( "boom_m" ),
						Util.sound_loader( "boom_l" ) ]

	@staticmethod
	def max_width():
		return Boom.imagesets[Boom.SIZE_LARGE].get_width()

	# Choose a new frame
	def __newframe(self):
		self.images_frame = (self.images_frame+1) % len(self.images)
		self.image = self.images[self.images_frame]

	# --------------------------
	# New Sprite
	# --------------------------
	def __init__( self, _size, _pos, _speed, _life ):
		"""
		_size = SIZE_SMALL, SIZE_MEDIUM, SIZE_LARGE or None to preload all images
		_pos = top left starting position
		_speed = starting speed
		_life = lifetime in seconds
		"""

		if not Boom.imagesets:
			Boom.preload()

		# Always init the sprite
		pygame.sprite.Sprite.__init__( self )

		self.pos = list(_pos)
		self.speed = _speed
		self.life = _life
		self.imageset = Boom.imagesets[_size].shared_copy()

		self.image, self.rect = self.imageset.newframe( 0, self.pos )

		Boom.sounds[_size].play()

	#
	# Don't move it, but update frame
	#
	def update( self, seconds ):

		self.pos[0] += self.speed[0] * seconds
		self.pos[1] += self.speed[1] * seconds

		# Are we out of time? If so, suicide. Otherwise pick new frame
		self.life -= seconds
		if self.life<0:
			self.kill()
		else:
			self.image, self.rect = self.imageset.newframe( seconds, self.pos )
