# -----------------------------------------------------------------
# MySound
#
# This is just a tiny wrapper around pygame.mixer.sound to allow
# us a little bit more control. 
#
# Copyright 2005 Ron Dippold
# -----------------------------------------------------------------
import pygame, pygame.mixer


class MySound:
	"""
	Tiny wrapper around pygame.mixer.sound to allow us a bit more
	control.
	"""

	# If true, don't start any new sounds
	ismute = False

	@staticmethod
	def mute():
		"""Mute all sounds, don't play any new ones."""
		MySound.ismute = True
		if pygame.mixer:
			pygame.mixer.stop()
			

	@staticmethod
	def unmute():
		"""Allow sounds to be played again."""
		MySound.ismute = False

	@staticmethod
	def init():
		# See if the mixer is here, null it out if it doesn't work - called by game.py
		try:
			pygame.mixer.init()
		except:
			print "** pygame.mixer init failed - no sound **"
			pygame.mixer = None

	# -----------------------------------------------------
	#
	# Constructor
	#
	# -----------------------------------------------------
		
	def __init__( self, _fname, _vol ):
		"""
		_fname = The .wav filename
		_vol = volume (from 0.0 to 1.0)
		"""

		# If we have sounds, then make a sound, otherwise just
		# leave the sound empty (None)
		self.sound = None
		if pygame.mixer:
			try:
				self.sound = pygame.mixer.Sound( _fname )
			except:
				print "Warning: couldn't load sound", _fname
		self.set_volume( _vol )

		# just for debug
		self.name = _fname

	# -----------------------------------------------------
	#
	# Straight wraps of pygame.mixer.Sound functionality
	#
	# -----------------------------------------------------

	def fadeout( self, _msec ):
		"""fadeout in _msec milliseconds"""
		if self.sound:
			self.sound.fadeout( _msec )

	def get_length( self ):
		if self.sound:
			return self.sound.get_length()
		else:
			return 0.0

	def get_num_channels( self ):
		if self.sound:
			return self.get_num_channels()
		else:
			return 0

	def get_volume( self ):
		if self.sound:
			return self.sound.get_volume()
		else:
			return 1.0

	def play( self, _loops=0 ):
		"""
		Play new sound.
		_loops = number of extra times to play. -1 = forever
		"""
		if not MySound.ismute and self.sound:
			return self.sound.play( _loops )
		else:
			return 0

	def set_volume( self, _vol ):
		"""_vol = new volume, 0.0 (silent) to 1.0 (full)"""
		if self.sound:
			self.sound.set_volume( _vol )

	def stop( self ):
		"""Stop this sound on all channels."""
		if self.sound:
			self.sound.stop()
