# -----------------------------------------------------------------------------
# Keep track of the current score
#
# Copyright 2005 Ron Dippold
# -----------------------------------------------------------------------------

from TextSprite import FixedFontText

class Score( FixedFontText ):


	def __init__( self, _pos, _color=(255,255,255), _points=36, _digits=6 ):
		"""
		A fixed point score sprite.
		_pos = center position
		_color = (r,g,b) (default 255,255,255)
		_points = font size (default 36)
		_digits = max # of digits to hold (default 6)
		"""

		FixedFontText.__init__( self, None, _points, "0"*_digits, _color, _pos )
		self.digits = _digits
		self.max = int( '9'*_digits )
		self.multiplier = 1
		self.reset()

	def reset( self):
		"""
		Reset the score back to 0
		"""
		self.set_score( 0 )

	def set_multiplier( self, _factor ):
		"""
		Multiply all add_score by this
		"""
		self.multiplier = _factor


	def add_score( self, _value ):
		"""
		Add _value to the score
		"""
		self.set_score( self.value + int(_value*self.multiplier) )

	def set_score( self, _value ):
		"""
		Set the score to an absolute _value
		"""
		self.value = _value
		self.__update_image()

	def hiscore( self, _score ):
		"""
		Set value to the same as another Score(), if the
		other Score is greater. For hi scores. Returns
		True if it was changed.
		"""
		if self.value < _score.value:
			self.set_score( _score.value )
			return True
		else:
			return False

	def has_changed( self ):
		"""
		Returns True if the Score bitmap has changed, then resets it
		back to False, so you'd better draw it!
		"""
		if self.changed:
			self.changed = False
			return True
		else:
			return False

	def __update_image( self ):
		"""
		Update our bitmap
		"""

		self.changed = True
		# Update the sprite bitmap
		if self.value > self.max:
			text = "9" * self.digits
		else:
			text = "%0*d" % (self.digits,self.value)
		self.set_text( text )


	# -------------------------
	# de/serialize to file
	# -------------------------

	def write( self, _fname ):
		try:
			f = open( _fname, "w" )
			f.write( str(self.value) )
			f.close()
		except:
			# don't really care too much if this fails
			pass

	def read( self, _fname ):
		try:
			f = open( _fname, "r" )
			self.set_score( int(f.read()) )
			f.close()
		except:
			# don't really care too much if this fails
			pass

		
		
